"use strict";

exports.__esModule = true;
exports.default = focusWithOptions;

var _supportsFocusOptions = _interopRequireDefault(require("./supportsFocusOptions"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Copyright (c) Facebook, Inc. and its affiliates.
 * Copyright (c) 2018 Juan Valencia (https://github.com/calvellido/focus-options-polyfill/blob/master/LICENSE)
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * 
 */
var canUseFocusOptions = (0, _supportsFocusOptions.default)();

/**
 * Record the current scroll positions of all scrollable ancestors
 * of the element.
 */
function getScrollPositions(node) {
  var scrollablePositions = [];
  var rootScrollable = document.documentElement;
  var parentNode = node.parentElement;

  while (parentNode != null && parentNode !== rootScrollable) {
    if ( // $FlowFixMe: flow is wrong
    parentNode.offsetHeight < parentNode.scrollHeight || // $FlowFixMe: flow is wrong
    parentNode.offsetWidth < parentNode.scrollWidth) {
      scrollablePositions.push([parentNode, parentNode.scrollTop, parentNode.scrollLeft]);
    }

    parentNode = parentNode.parentElement;
  }

  if (rootScrollable != null) {
    scrollablePositions.push([rootScrollable, rootScrollable.scrollTop, rootScrollable.scrollLeft]);
  }

  return scrollablePositions;
}
/**
 * Restore the scroll positions of each element in the records.
 */


function restoreScrollPositions(scrollPositions) {
  for (var i = 0; i < scrollPositions.length; i++) {
    var scrollRecord = scrollPositions[i];
    var node = scrollRecord[0],
        scrollTop = scrollRecord[1],
        scrollLeft = scrollRecord[2];
    node.scrollTop = scrollTop;
    node.scrollLeft = scrollLeft;
  }
}
/**
 * A "polyfill" for element.focus({preventScroll: true});
 * https://caniuse.com/#feat=mdn-api_htmlelement_focus_preventscroll_option
 */


function focusWithOptions(node, options) {
  if (canUseFocusOptions) {
    node.focus(options);
  } else {
    var scrollPositions;

    if (options != null && options.preventScroll === true) {
      scrollPositions = getScrollPositions(node);
    }

    node.focus();

    if (scrollPositions != null) {
      restoreScrollPositions(scrollPositions);
    }
  }
}

module.exports = exports.default;