"use strict";

exports.__esModule = true;
exports.default = getAccessibilityElementWithSideEffect;

/**
 * Copyright (c) Nicolas Gallagher.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * 
 */
var roleToElementType = {
  article: 'article',
  banner: 'header',
  blockquote: 'blockquote',
  code: 'code',
  complementary: 'aside',
  contentinfo: 'footer',
  definition: 'dfn',
  deletion: 'del',
  emphasis: 'em',
  figure: 'figure',
  insertion: 'ins',
  form: 'form',
  label: 'label',
  link: 'a',
  list: 'ul',
  listitem: 'li',
  main: 'main',
  navigation: 'nav',
  region: 'section',
  strong: 'strong'
};
var emptyObject = {};
/**
 * Converts accessibility props into native HTML semantics where possible, and mutates
 * the props to remove redundant information.
 */

function getAccessibilityElementWithSideEffect(props) {
  if (props === void 0) {
    props = emptyObject;
  }

  var elementType;
  var _props = props,
      accessibilityLevel = _props.accessibilityLevel,
      accessibilityRole = _props.accessibilityRole,
      href = _props.href; // Anything with an 'href' needs to be an anchor tag. Don't remove the role!

  if (href != null) {
    elementType = 'a';
  } // Heading tags are determined from role and level (default is 'h2')
  else if (accessibilityRole === 'heading') {
      elementType = 'h2';
      props.accessibilityRole = null;

      if (accessibilityLevel != null && typeof accessibilityLevel === 'number' && accessibilityLevel < 7) {
        elementType = "h" + accessibilityLevel;
        props.accessibilityLevel = null;
      }
    } // Other roles may be converted to HTML tag equivalents
    else if (accessibilityRole != null) {
        elementType = roleToElementType[props.accessibilityRole];
        props.accessibilityRole = null;
      }

  return elementType;
}

module.exports = exports.default;