"use strict";

exports.__esModule = true;
exports.activeModality = activeModality;
exports.blur = blur;
exports.clear = clear;
exports.focus = focus;
exports.getLayout = getLayout;

var _focusWithOptions = _interopRequireDefault(require("./__modules__/focusWithOptions"));

var _getBoundingClientRect = _interopRequireDefault(require("./__modules__/getBoundingClientRect"));

var _modality = require("./__modules__/modality");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Copyright (c) Nicolas Gallagher.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * 
 */
var focusableElements = {
  A: true,
  BUTTON: true,
  INPUT: true,
  SELECT: true,
  TEXTAREA: true
};
/**
 * Get the currently active modality
 */

function activeModality() {
  return (0, _modality.getActiveModality)();
}
/**
 * Blur an element
 */


function blur(ref) {
  var node = ref.current;

  if (node != null) {
    try {
      node.blur();
    } catch (err) {}
  }
}
/**
 * Clear the text from an input
 */


function clear(ref) {
  var node = ref.current;

  if (node != null && typeof node.value === 'string') {
    node.value = '';
  }
}
/**
 * Focus an element
 */


function focus(ref, options) {
  var node = ref.current;

  if (node != null) {
    try {
      var name = node.nodeName; // A tabIndex of -1 allows the element to be programmatically focused but prevents keyboard
      // focus, so we don't want to set the value on elements configured to receive keyboard focus.

      if (focusableElements[name] == null && node.getAttribute('tabIndex') == null) {
        node.setAttribute('tabIndex', '-1');
      }

      (0, _focusWithOptions.default)(node, options);
    } catch (err) {}
  }
}
/**
 * Measure the layout of an element
 */


function getLayout(ref) {
  var node = ref.current;

  if (node != null) {
    return (0, _getBoundingClientRect.default)(node);
  }
}