"use strict";

exports.__esModule = true;
exports.default = void 0;

var React = _interopRequireWildcard(require("react"));

var _createElement = _interopRequireWildcard(require("../create-element"));

var _getAccessibilityElementWithSideEffect = _interopRequireDefault(require("../__modules__/getAccessibilityElementWithSideEffect"));

var _TextAncestorContext = _interopRequireDefault(require("./TextAncestorContext"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

/**
 * Copyright (c) Nicolas Gallagher.
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * 
 */
var Text = React.forwardRef(function (props, forwardedRef) {
  var children = props.children,
      direction = props.direction,
      href = props.href,
      hrefAttrs = props.hrefAttrs,
      lang = props.lang;
  var hasTextAncestor = React.useContext(_TextAncestorContext.default); // If this Text is nested within another text rendering a DOM node if there are no props or ref

  if (hasTextAncestor && forwardedRef == null && props.children != null && Object.keys(props).length === 1) {
    return props.children;
  } // Construct the props


  var elementProps = (0, _createElement.filterProps)(props);
  elementProps.children = children;
  elementProps.classList = [classes.text, hasTextAncestor === true && classes.textHasAncestor];
  elementProps.dir = direction !== undefined ? direction : 'auto';
  elementProps.lang = lang;
  elementProps.ref = forwardedRef;

  if (href) {
    elementProps.href = href;

    if (hrefAttrs != null) {
      var download = hrefAttrs.download,
          rel = hrefAttrs.rel,
          target = hrefAttrs.target;

      if (download != null) {
        elementProps.download = download;
      }

      if (rel != null) {
        elementProps.rel = rel;
      }

      if (typeof target === 'string') {
        elementProps.target = '_' + target;
      }
    }
  } // Construct the element


  var accessibilityElementType = (0, _getAccessibilityElementWithSideEffect.default)(elementProps);
  var elementType = accessibilityElementType || (hasTextAncestor ? 'span' : 'div');
  var element = (0, _createElement.default)(elementType, elementProps);
  return hasTextAncestor ? element : React.createElement(_TextAncestorContext.default.Provider, {
    value: true
  }, element);
});
Text.displayName = 'Text';
var classes = (0, _createElement.createStyleRules)({
  text: {
    border: '0 solid black',
    boxSizing: 'border-box',
    color: 'black',
    display: 'inline',
    font: '14px System',
    margin: 0,
    padding: 0,
    whiteSpace: 'pre-wrap',
    wordWrap: 'break-word'
  },
  textHasAncestor: {
    color: 'inherit',
    font: 'inherit',
    whiteSpace: 'inherit'
  }
});
var _default = Text;
exports.default = _default;
module.exports = exports.default;