"use strict";

exports.__esModule = true;
exports.default = useFocusEvents;

var _useEvent = _interopRequireDefault(require("../use-event"));

var _useLayoutEffect = _interopRequireDefault(require("../__modules__/useLayoutEffect"));

var _index = require("../index");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Copyright (c) Nicolas Gallagher.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * 
 */

/**
 * useFocusEvents implementation
 */
var bubbleOptions = {
  passive: true
};
var captureOptions = {
  capture: true,
  passive: true
};

function useFocusEvents(targetRef, config) {
  var autoFocus = config.autoFocus,
      disabled = config.disabled,
      onBlur = config.onBlur,
      onBlurCapture = config.onBlurCapture,
      onFocus = config.onFocus,
      onFocusCapture = config.onFocusCapture,
      onFocusChange = config.onFocusChange; // Event handles (these events do not bubble)

  var blurHandle = (0, _useEvent.default)('blur', bubbleOptions);
  var focusHandle = (0, _useEvent.default)('focus', bubbleOptions);
  var blurCaptureHandle = (0, _useEvent.default)('blur', captureOptions);
  var focusCaptureHandle = (0, _useEvent.default)('focus', captureOptions);
  (0, _useLayoutEffect.default)(function () {
    var target = targetRef.current;

    function blurListener(e) {
      if (onBlur != null) {
        onBlur(e);
      }

      if (onFocusChange != null) {
        onFocusChange(false, e);
      }
    }

    function focusListener(e) {
      if (onFocus != null) {
        onFocus(e);
      }

      if (onFocusChange != null) {
        onFocusChange(true, e);
      }
    }

    if (target != null) {
      blurHandle.setListener(target, !disabled ? blurListener : null);
      focusHandle.setListener(target, !disabled ? focusListener : null);
      blurCaptureHandle.setListener(target, !disabled && onBlurCapture || null);
      focusCaptureHandle.setListener(target, !disabled && onFocusCapture || null);
    }

    if (autoFocus) {
      (0, _index.focus)(targetRef);
    }
  }, [targetRef, disabled, blurHandle, focusHandle, blurCaptureHandle, focusCaptureHandle, onBlur, onBlurCapture, onFocus, onFocusCapture, onFocusChange, autoFocus]);
}

module.exports = exports.default;