"use strict";

exports.__esModule = true;
exports.default = useFocusVisibleEvents;

var React = _interopRequireWildcard(require("react"));

var _modality = require("../__modules__/modality");

var _useFocusEvents = _interopRequireDefault(require("../use-focus-events"));

var _useFocusWithinEvents = _interopRequireDefault(require("../use-focus-within-events"));

var _useLayoutEffect = _interopRequireDefault(require("../__modules__/useLayoutEffect"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

/**
 * Copyright (c) Nicolas Gallagher.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * 
 */

/**
 * useFocusVisibleEvents implementation
 *
 * Respond to changes in *visibile* focus. Focus is visible whenever a keyboard is used.
 */
function useFocusVisibleEvents(targetRef, config) {
  var disabled = config.disabled,
      onFocusVisibleChange = config.onFocusVisibleChange,
      onFocusVisibleWithinChange = config.onFocusVisibleWithinChange;
  (0, _useLayoutEffect.default)(function () {
    var removeModalityListener = (0, _modality.addModalityListener)(function (modality, isFocusVisible) {
      if (onFocusVisibleChange && !isFocusVisible) {
        onFocusVisibleChange(false);
      }

      if (onFocusVisibleWithinChange && !isFocusVisible) {
        onFocusVisibleWithinChange(false);
      }
    });
    return removeModalityListener;
  }, [onFocusVisibleChange, onFocusVisibleWithinChange]); // Listen to changes in the local focus. Any time the local focus changes, the
  // component is notified of a change in local visibility only.

  var focusEventsConfig = React.useMemo(function () {
    return {
      disabled: disabled,
      onFocusChange: function onFocusChange(isFocused, e) {
        var focusVisible = (0, _modality.getActiveModality)() === 'keyboard';

        if (onFocusVisibleChange) {
          onFocusVisibleChange(isFocused && focusVisible);
        }
      }
    };
  }, [disabled, onFocusVisibleChange]);
  (0, _useFocusEvents.default)(targetRef, focusEventsConfig); // Listen to changes in the subtree focus.

  var focusWithinEventsConfig = React.useMemo(function () {
    return {
      disabled: disabled,
      onBlurWithin: function onBlurWithin(e) {
        var focusVisible = (0, _modality.getActiveModality)() === 'keyboard';

        if (onFocusVisibleWithinChange) {
          onFocusVisibleWithinChange(focusVisible);
        }
      },
      onFocusWithin: function onFocusWithin(e) {
        var focusVisible = (0, _modality.getActiveModality)() === 'keyboard';

        if (onFocusVisibleWithinChange) {
          onFocusVisibleWithinChange(focusVisible);
        }
      }
    };
  }, [disabled, onFocusVisibleWithinChange]);
  (0, _useFocusWithinEvents.default)(targetRef, focusWithinEventsConfig);
}

module.exports = exports.default;