"use strict";

exports.__esModule = true;
exports.default = useFocusWithinEvents;

var React = _interopRequireWildcard(require("react"));

var _useEvent = _interopRequireDefault(require("../use-event"));

var _useLayoutEffect = _interopRequireDefault(require("../__modules__/useLayoutEffect"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

/**
 * Copyright (c) Nicolas Gallagher.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * 
 */

/**
 * useFocusWithin implementation
 */
var passiveOptions = {
  passive: true
};

function useFocusWithinEvents(targetRef, config) {
  var focusWithinRef = React.useRef(false);
  var disabled = config.disabled,
      onBlurWithin = config.onBlurWithin,
      onFocusWithin = config.onFocusWithin,
      onFocusWithinChange = config.onFocusWithinChange; // Event handles (these events bubble)
  // NOTE: 'beforeblur' and 'afterblur' are custom events dispatched by React
  // either side of a focused element being detached from the DOM.

  var focusInHandle = (0, _useEvent.default)('focusin', passiveOptions);
  var focusOutHandle = (0, _useEvent.default)('focusout', passiveOptions); // const afterBlurHandle = useEvent('afterblur', passiveOptions);
  // const beforeBlurHandle = useEvent('beforeblur', passiveOptions);

  var focusInListener = React.useCallback(function (e) {
    if (onFocusWithin != null) {
      onFocusWithin(e);
    }

    if (focusWithinRef.current === false) {
      focusWithinRef.current = true;

      if (onFocusWithinChange != null) {
        onFocusWithinChange(true);
      }
    }
  }, [focusWithinRef, onFocusWithin, onFocusWithinChange]);
  var focusOutListener = React.useCallback(function (e) {
    var target = targetRef.current;

    if (onBlurWithin != null) {
      onBlurWithin(e);
    }

    if (focusWithinRef.current === true && target != null) {
      // Ignore focus moving within the subtree
      if (!target.contains(e.relatedTarget)) {
        focusWithinRef.current = false;

        if (onFocusWithinChange) {
          onFocusWithinChange(false);
        }
      }
    }
  }, [onBlurWithin, onFocusWithinChange, targetRef]);
  /*
  function beforeBlurListener(e) {
    if (onBeforeBlurWithin != null) {
      onBeforeBlurWithin(e);
    }
     if (onAfterBlurWithin != null) {
      afterBlurHandle.setListener(document, onAfterBlurWithin);;
      afterBlurHandle.clear();
    }
  }
  */

  (0, _useLayoutEffect.default)(function () {
    var target = targetRef.current;

    if (target !== null) {
      focusInHandle.setListener(target, !disabled ? focusInListener : null);
      focusOutHandle.setListener(target, !disabled ? focusOutListener : null); // beforeBlurHandle.setListener(target, !disabled ? beforeBlurListener : null);
    }
  }, [targetRef, focusInListener, focusOutListener, focusInHandle, disabled, focusOutHandle]);
}

module.exports = exports.default;