"use strict";

exports.__esModule = true;
exports.default = useHoverEvents;

var React = _interopRequireWildcard(require("react"));

var _useEvent = _interopRequireDefault(require("../use-event"));

var _useLayoutEffect = _interopRequireDefault(require("../__modules__/useLayoutEffect"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

/**
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * 
 */
var bubbleOptions = {
  passive: true
};

function useHoverEvents(targetRef, config) {
  var disabled = config.disabled,
      onHoverStart = config.onHoverStart,
      onHoverChange = config.onHoverChange,
      onHoverUpdate = config.onHoverUpdate,
      onHoverEnd = config.onHoverEnd;
  var hoverRef = React.useRef(false);
  var pointerMoveHandle = (0, _useEvent.default)('pointermove', bubbleOptions);
  var pointerOverHandle = (0, _useEvent.default)('pointerover', bubbleOptions);
  var pointerOutHandle = (0, _useEvent.default)('pointerout', bubbleOptions);
  var pointerMoveListener = React.useCallback(function (e) {
    if (hoverRef.current === true && e.pointerType !== 'touch') {
      if (onHoverUpdate != null) {
        // Not all browsers have these properties
        if (e.x == null) {
          e.x = e.clientX;
        }

        if (e.y == null) {
          e.y = e.clientY;
        }

        onHoverUpdate(e);
      }
    }
  }, [onHoverUpdate]);
  var pointerOutListener = React.useCallback(function (e) {
    var target = targetRef.current;

    if (target != null && hoverRef.current === true && e.pointerType !== 'touch') {
      var outsideTarget = !target.contains(e.relatedTarget);

      if (outsideTarget) {
        hoverRef.current = false;

        if (onHoverEnd != null) {
          onHoverEnd(e);
        }

        if (onHoverChange != null) {
          onHoverChange(false);
        } // Remove the listeners once finished


        pointerMoveHandle.setListener(target, null);
        pointerOutHandle.setListener(target, null);
      }
    }
  }, [onHoverEnd, onHoverChange, targetRef, pointerMoveHandle, pointerOutHandle]);
  var pointerOverListener = React.useCallback(function (e) {
    var target = targetRef.current;

    if (target != null && hoverRef.current === false && e.pointerType !== 'touch') {
      hoverRef.current = true;

      if (onHoverStart != null) {
        onHoverStart(e);
      }

      if (onHoverChange != null) {
        onHoverChange(true);
      } // Set the listeners needed for the rest of the hover gesture


      if (onHoverUpdate != null) {
        pointerMoveHandle.setListener(target, !disabled ? pointerMoveListener : null);
      }

      pointerOutHandle.setListener(target, !disabled ? pointerOutListener : null);
    }
  }, [disabled, onHoverChange, onHoverStart, onHoverUpdate, pointerMoveHandle, pointerMoveListener, pointerOutHandle, pointerOutListener, targetRef]);
  (0, _useLayoutEffect.default)(function () {
    var target = targetRef.current;

    if (target !== null) {
      pointerOverHandle.setListener(target, !disabled ? pointerOverListener : null);
    }
  }, [disabled, pointerOverHandle, pointerOverListener, targetRef]);
}

module.exports = exports.default;