"use strict";

exports.__esModule = true;
exports.default = useKeyboardEvents;

var _useEvent = _interopRequireDefault(require("../use-event"));

var _useLayoutEffect = _interopRequireDefault(require("../__modules__/useLayoutEffect"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Copyright (c) Nicolas Gallagher.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * 
 */

/**
 * useKeyboardEvents implementation
 */
var captureOptions = {
  capture: true
};
var passiveOptions = {
  passive: true
};
var capturePassiveOptions = {
  capture: true,
  passive: true
}; // TODO: https://github.com/w3c/uievents/issues/202

function useKeyboardEvents(targetRef, config) {
  var disabled = config.disabled,
      onKeyDown = config.onKeyDown,
      onKeyDownCapture = config.onKeyDownCapture,
      onKeyUp = config.onKeyUp,
      onKeyUpCapture = config.onKeyUpCapture; // Event handles (these events bubble)

  var keyDownHandle = (0, _useEvent.default)('keydown');
  var keyDownCaptureHandle = (0, _useEvent.default)('keydown', captureOptions);
  var keyUpHandle = (0, _useEvent.default)('keyup', passiveOptions);
  var keyUpCaptureHandle = (0, _useEvent.default)('keyup', capturePassiveOptions);
  (0, _useLayoutEffect.default)(function () {
    var target = targetRef.current;

    var createKeyListener = function createKeyListener(listener) {
      return function keyListener(e) {
        if (!e.isComposing && e.keyCode !== 229) {
          if (listener != null) {
            listener(e);
          }
        }
      };
    };

    if (target != null) {
      keyDownHandle.setListener(target, !disabled && createKeyListener(onKeyDown) || null);
      keyDownCaptureHandle.setListener(target, !disabled && createKeyListener(onKeyDownCapture) || null);
      keyUpHandle.setListener(target, !disabled && createKeyListener(onKeyUp) || null);
      keyUpCaptureHandle.setListener(target, !disabled && createKeyListener(onKeyUpCapture) || null);
    }
  }, [disabled, keyDownCaptureHandle, keyDownHandle, keyUpCaptureHandle, keyUpHandle, onKeyDown, onKeyDownCapture, onKeyUp, onKeyUpCapture, targetRef]);
}

module.exports = exports.default;