"use strict";

exports.__esModule = true;
exports.default = useLayoutEvents;

var _supportsDOM = _interopRequireDefault(require("../__modules__/supportsDOM"));

var _getBoundingClientRect = _interopRequireDefault(require("../__modules__/getBoundingClientRect"));

var _useLayoutEffect = _interopRequireDefault(require("../__modules__/useLayoutEffect"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Copyright (c) Nicolas Gallagher.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * 
 */
var ON_LAYOUT_KEY = '__reactOnLayout';
var ON_LAYOUT_CONTENT_BOX_KEY = '__reactOnLayoutContentBox';
var didWarn = false;
var resizeObserver = null;

function createLayoutEvent(target, layout) {
  var event = {
    // $FlowFixMe
    nativeEvent: {
      layout: layout
    },
    timeStamp: Date.now()
  };
  Object.defineProperty(event.nativeEvent, 'target', {
    enumerable: true,
    get: function get() {
      return target;
    }
  });
  return event;
}

function getResizeObserver() {
  if ((0, _supportsDOM.default)() && typeof window.ResizeObserver !== 'undefined') {
    if (resizeObserver == null) {
      resizeObserver = new window.ResizeObserver(function (entries) {
        entries.forEach(function (entry) {
          var contentRect = entry.contentRect,
              target = entry.target;
          var onLayout = target[ON_LAYOUT_KEY];
          var onLayoutContentBox = target[ON_LAYOUT_CONTENT_BOX_KEY];

          if (onLayout != null) {
            // border-box dimensions are not supported by the polyfill or
            // many native implementations
            var borderRect = (0, _getBoundingClientRect.default)(target);
            var event = createLayoutEvent(target, borderRect);
            onLayout(event);
          }

          if (onLayoutContentBox) {
            var _event = createLayoutEvent(target, contentRect);

            onLayoutContentBox(_event);
          }
        });
      });
    }
  } else if (!didWarn) {
    if (process.env.NODE_ENV !== 'production' && process.env.NODE_ENV !== 'test') {
      console.warn('onLayout relies on ResizeObserver which is not supported by your browser. ' + 'Please include a polyfill, e.g., https://github.com/que-etc/resize-observer-polyfill.');
      didWarn = true;
    }
  }

  return resizeObserver;
} // TODO: offsetWidth / offsetHeight
// TODO: multiple uses, push all listeners into an array on the expando


function useLayoutEvents(targetRef, config) {
  var observer = getResizeObserver();
  var onLayout = config.onLayout,
      onLayoutContentBox = config.onLayoutContentBox;
  (0, _useLayoutEffect.default)(function () {
    var target = targetRef.current;

    if (target != null && observer != null && (onLayout != null || onLayoutContentBox != null)) {
      observer.observe(target);
      target[ON_LAYOUT_KEY] = onLayout;
      target[ON_LAYOUT_CONTENT_BOX_KEY] = onLayoutContentBox;
    }

    return function () {
      if (target != null && observer != null) {
        observer.unobserve(target);
        delete target[ON_LAYOUT_KEY];
        delete target[ON_LAYOUT_CONTENT_BOX_KEY];
      }
    };
  }, [targetRef, onLayout, onLayoutContentBox, observer]);
}

module.exports = exports.default;