/**
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 *  strict-local
 * @format
 */
'use strict';

exports.__esModule = true;
exports.default = usePanEvents;

var React = _interopRequireWildcard(require("react"));

var _PanResponder = _interopRequireDefault(require("./PanResponder"));

var _useResponderEvents = _interopRequireDefault(require("../use-responder-events"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function usePanEvents(targetRef, config) {
  var panResponderRef = React.useRef < _PanResponder.default > null;

  if (panResponderRef.current == null) {
    panResponderRef.current = new _PanResponder.default(config);
  }

  var panResponder = panResponderRef.current; // Re-configure to use the current node and configuration.

  React.useEffect(function () {
    panResponder.configure(config);
  }, [config, panResponder]); // Reset the `panResponder` when cleanup needs to occur. This is
  // a separate effect because we do not want to rest the responder when `config` changes.

  React.useEffect(function () {
    return function () {
      panResponder.reset();
    };
  }, [panResponder]);
  React.useDebugValue(config);
  (0, _useResponderEvents.default)(targetRef, panResponder.getEventHandlers());
}

module.exports = exports.default;