"use strict";

exports.__esModule = true;
exports.default = void 0;

var React = _interopRequireWildcard(require("react"));

var _createElement = _interopRequireWildcard(require("../create-element"));

var _getAccessibilityElementWithSideEffect = _interopRequireDefault(require("../__modules__/getAccessibilityElementWithSideEffect"));

var _TextAncestorContext = _interopRequireDefault(require("../text/TextAncestorContext"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

/**
 * Copyright (c) Nicolas Gallagher.
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * 
 */
var View = React.forwardRef(function (props, forwardedRef) {
  var children = props.children,
      direction = props.direction,
      href = props.href,
      hrefAttrs = props.hrefAttrs;

  if (process.env.NODE_ENV !== 'production') {
    React.Children.toArray(children).forEach(function (item) {
      if (typeof item === 'string') {
        console.error("Unexpected text node: " + item + ". A text node cannot be a child of a <View>.");
      }
    });
  }

  var hasTextAncestor = React.useContext(_TextAncestorContext.default); // Construct the props

  var elementProps = (0, _createElement.filterProps)(props);
  elementProps.children = children;
  elementProps.classList = [classes.view, hasTextAncestor && classes.viewHasTextAncestor];
  elementProps.dir = direction;
  elementProps.ref = forwardedRef;

  if (href) {
    elementProps.href = href;

    if (hrefAttrs != null) {
      var download = hrefAttrs.download,
          rel = hrefAttrs.rel,
          target = hrefAttrs.target;

      if (download != null) {
        elementProps.download = download;
      }

      if (rel != null) {
        elementProps.rel = rel;
      }

      if (typeof target === 'string') {
        elementProps.target = '_' + target;
      }
    }
  } // Construct the element


  var accessibilityElementType = (0, _getAccessibilityElementWithSideEffect.default)(elementProps);
  var elementType = accessibilityElementType || 'div';
  var element = (0, _createElement.default)(elementType, elementProps); // Reset the context for views nested within text

  return hasTextAncestor ? React.createElement(_TextAncestorContext.default.Provider, {
    value: false
  }, element) : element;
});
View.displayName = 'View';
var classes = (0, _createElement.createStyleRules)({
  view: {
    alignItems: 'stretch',
    border: '0 solid black',
    boxSizing: 'border-box',
    display: 'flex',
    flexBasis: 'auto',
    flexDirection: 'column',
    flexShrink: 0,
    margin: 0,
    minHeight: 0,
    minWidth: 0,
    padding: 0,
    position: 'relative',
    zIndex: 0
  },
  viewHasTextAncestor: {
    display: 'inline-flex'
  }
});
var _default = View;
exports.default = _default;
module.exports = exports.default;